==> visual-third-party-0.0.2-sources.jar: com/tenqube/visual_third/Constants.java <==
package com.tenqube.visual_third;

public final class Constants {

    public static final String VISUAL_TAG = "VisualFlow";

    public static boolean sLogger;
    public static final String ACTION_TRAN_POPUP = "tenqube.intent.action.ACTION_TRAN_POPUP";

    public static final String INTENT_POPUP_KEY = "popup_data";

    public static final String DEFAULT_AD_RATIO = "2:8";

    public static final String AD_TYPE_ADMOB = "admob";

    public static final String AD_TYPE_MOBON = "mobon";

    public static final String SUCCESS = "success";
    public static final String FAIL = "fail";
    public static final String NONE = "none";

    public enum ProgressType {
        BULK("bulk"),
        SYNC("sync"),
        DEFAULT("default");

        public String name;
        ProgressType(String name) {

            this.name = name;
        }
    }

    public enum Gender {
        MALE,
        FEMALE
    }

    public enum ReportAlarmType {
        DAILY,
        WEEKLY,
        MONTHLY
    }
    public static final class ProviderType {
        public static final int MONTH = 1;
        public static final int WEEK = 2;
        public static final int CARD = 3;
        public static final int CATEGORY = 4;
        public static final int KEYWORD = 5;
    }

    public static final class NotificationType {
        public static final String MONTHLY = "monthly";
        public static final String WEEKLY_MON = "weekly_mon";
        public static final String WEEKLY_FRI = "weekly_fri";
        public static final String DAILY = "daily";

    }

    public static final class AggregateType {
        public static final int NONE = 0;
        public static final int MONTH = 1;
        public static final int LCODE = 2;
        public static final int MCODE = 3;
        public static final int CARD_TYPE = 4;
        public static final int FRANCHISE = 5;
        public static final int KEYWORD = 6;
        public static final int DATE = 7;
    }

    public static final class COMPANY_ID {
        public static final int UNCATE_ETC = 1260117;
        public static final int DEPOSIT_ETC = 3983462;
        public static final int WITHDRAW_ETC = 3983436;

    }

    public static final class CATEGORY_CODE {
        public static final int UNCATE_ETC = 101010;
        public static final int WITHDRAW_ETC = 841010;

        public static final int DEPOSIT_ETC = 901010;
    }

    public static final class LCODE {
        public static final int MONTHLY = 11;
        public static final int WEEKLY = 2;

        public static final int UNCATE = 10;
        public static final int FOOD = 22;
        public static final int CAFE = 24;
        public static final int ALCOHOL = 26;

        public static final int MART = 32;
        public static final int ONLINE = 34;
        public static final int SHOPPING = 36;

        public static final int FINANCE = 42;
        public static final int HEALTHCARE = 44;
        public static final int BEAUTY = 46;

        public static final int LIVINGS = 52;
        public static final int EDUCATION = 54;
        public static final int CULTURE = 56;

        public static final int TRANSPORT = 62;
        public static final int LEPORTS = 64;
        public static final int TRAVEL = 66;

        public static final int FAMILY_EVENT = 82;
        public static final int WITHDRAW_CODE = 84;
        public static final int WITHDRAW_MOVING_ASSET = 88;

        public static final int DEPOSIT_ETC = 90;
        public static final int INCOME_MAIN = 92;
        public static final int INCOME_SUB = 94;
        public static final int DEPOSIT_LOAN = 96;
        public static final int DEPOSIT_MOVING_ASSET = 98;
    }

    public static final class MCODE {
        public static final int FASTFOOD = 2212;

        public static final int HOSPITAL = 4413;
        public static final int MID_PHARMACY = 4414;
        public static final int MID_DENTIST = 4412;
        public static final int MID_CLINIC = 4411;

        public static final int TAXI = 6216;
        public static final int COFFEE = 2411;
        public static final int NAIL = 4614;
        public static final int HAIR = 4611;
        public static final int ALCOHOL = 2613;
        public static final int MOVIE = 5611;
        public static final int BOOK = 5612;
        public static final int MART = 3216;
        public static final int CONVENIENCE = 3211;

    }

    public static final int COFFEE_TYPE_COUNTRY = 0;
    public static final int COFFEE_TYPE_COUNTRY_AMOUNT = 1;

    public static final int ALCOHOL_TYPE = 0;
    public static final int ALCOHOL_TYPE_IMAGE = 1;

    public static final int SUM = 0;
    public static final int CNT = 1;
    public static final int AVG = 2;
    public static final int TRAN_IDS = 3;



    public final class SignupResult {
        public static final int SUCCESS = 0;

        public static final int SERVER_ERROR = 1;
        public static final int NETWORK_ERROR = 2;
        public static final int ALREADY_JOINED = 3;


    }
    public static final String SAMSUNG_PAY = "com.samsung.android.spay";
    public static final String DEV = "dev";
    public static final String PROD = "prod";

    public static final int RULE_VERSION = 214;
    public static final int CATEGORY_VERSION = 11;
    public static final int CLIP_CATEGORY_VERSION = 8;
    public static final int ANALYSIS_VERSION = 1;
    public static final int NOTIFICATION_VERSION = 1;
    public static final int NOTIFICATION_DIVIDER = 120;

    public static final int PKG_VERSION = 1;


    public static final int FROM = 0;
    public static final int TO = 1;



}

==> visual-third-party-1.1.0-sources.jar: com/tenqube/visual_third/Constants.java <==
package com.tenqube.visual_third;

public final class Constants {


    public static final class AggregateType {
        public static final int NONE = 0;
        public static final int MONTH = 1;
        public static final int LCODE = 2;
        public static final int MCODE = 3;
        public static final int CARD_TYPE = 4;
        public static final int FRANCHISE = 5;
        public static final int KEYWORD = 6;
    }

    public static final class LCODE {
        public static final int UNCATE = 10;
        public static final int FOOD = 22;
        public static final int CAFE = 24;
        public static final int ALCOHOL = 26;

        public static final int MART = 32;
        public static final int ONLINE = 34;
        public static final int SHOPPING = 36;

        public static final int FINANCE = 42;
        public static final int HEALTHCARE = 44;
        public static final int BEAUTY = 46;

        public static final int LIVINGS = 52;
        public static final int EDUCATION = 54;
        public static final int CULTURE = 56;

        public static final int TRANSPORT = 62;
        public static final int LEPORTS = 64;
        public static final int TRAVEL = 66;

        public static final int FAMILY_EVENT = 82;
        public static final int WITHDRAW_CODE = 84;
        public static final int WITHDRAW_MOVING_ASSET = 88;

        public static final int DEPOSIT_ETC = 90;
        public static final int INCOME_MAIN = 92;
        public static final int INCOME_SUB = 94;
        public static final int DEPOSIT_LOAN = 96;
        public static final int DEPOSIT_MOVING_ASSET = 98;
    }

    public static final class MCODE {
        public static final int FASTFOOD = 2212;

        public static final int HOSPITAL = 4413;
        public static final int MID_PHARMACY = 4414;
        public static final int MID_DENTIST = 4412;
        public static final int MID_CLINIC = 4411;

        public static final int TAXI = 6216;
        public static final int COFFEE = 2411;
        public static final int NAIL = 4614;
        public static final int HAIR = 4611;
        public static final int ALCOHOL = 2613;
        public static final int MOVIE = 5611;
        public static final int BOOK = 5612;
        public static final int MART = 3216;
        public static final int CONVENIENCE = 3211;

    }

    public static final int COFFEE_TYPE_COUNTRY = 0;
    public static final int COFFEE_TYPE_COUNTRY_AMOUNT = 1;

    public static final int ALCOHOL_TYPE = 0;
    public static final int ALCOHOL_TYPE_IMAGE = 1;

    public static final int SUM = 0;
    public static final int CNT = 1;
    public static final int AVG = 2;
    public static final int TRAN_IDS = 3;



    public final class SignupResult {
        public static final int SUCCESS = 0;
        public static final int FAIL = 1;
        public static final int ALREADY_JOINED = 2;


    }
    public static final String SAMSUNG_PAY = "com.samsung.android.spay";
    public static final String DEV = "dev";
    public static final String PROD = "prod";

    public static final int RULE_VERSION = 214;
    public static final int CATEGORY_VERSION = 12;
    public static final int ANALYSIS_VERSION = 1;


    public static final int FROM = 0;
    public static final int TO = 1;



}
